from sqlalchemy import String, Integer, ForeignKey
from sqlalchemy.orm import Mapped, relationship,mapped_column
from .base import Base


class City(Base):
    __tablename__ = 'CITY'
    id:Mapped[int]= mapped_column(Integer,autoincrement=True, primary_key=True,unique=True,nullable=False,name='ID',)
    name:Mapped[str]= mapped_column(String(255), name='NAME')
    code:Mapped[str]= mapped_column(String(255), name='CODE')
    department_id:Mapped[int]= mapped_column(Integer, ForeignKey('DEPARTMENT.ID'), name='DEPARTMENT_ID')



"""Module Entity Player"""
from datetime import datetime
from sqlalchemy import String, Integer
from sqlalchemy.orm import Mapped, mapped_column
from sqlalchemy import DateTime
from .base import Base


class Player(Base):
    """Entity Player"""
    __tablename__ = 'PLAYER'
    id:Mapped[int]= mapped_column(Integer,autoincrement=True, primary_key=True,unique=True,nullable=False,name='ID',)
    weight:Mapped[int]= mapped_column(Integer, name='WEIGHT')
    hight:Mapped[int]= mapped_column(Integer, name='HIGHT')
    dorsal_number:Mapped[str]= mapped_column(String(255), name='DORSAL_NUMBER')
    position:Mapped[str]= mapped_column(String(255), name='POSITION')
    skil_ful_foot:Mapped[str]= mapped_column(String(255), name='SKIL_FUL_FOOT')
    is_full_profile:Mapped[bool]= mapped_column(Integer, name='IS_FULL_PROFILE')
    goals:Mapped[int]= mapped_column(Integer, name='GOALS')
    assists:Mapped[int]= mapped_column(Integer, name='ASSISTS')
    goals_againts:Mapped[int]= mapped_column(Integer, name='GOALS_AGAINTS')
    red_cards:Mapped[int]= mapped_column(Integer, name='RED_CARDS')
    yellow_cards:Mapped[int]= mapped_column(Integer, name='YELLOW_CARDS')
    games_played:Mapped[int]= mapped_column(Integer, name='GAMES_PLAYED')
    titles:Mapped[int]= mapped_column(Integer, name='TITLES')
    created_at: Mapped[datetime] = mapped_column(DateTime, default=datetime.now, name='CREATED_AT')
    updated_at: Mapped[datetime] = mapped_column(DateTime, default=datetime.now, onupdate=datetime.now, name='UPDATED_AT')


"""Module for User entity"""
from datetime import datetime
from sqlalchemy import String, DateTime, Integer, ForeignKey
from sqlalchemy.orm import Mapped, mapped_column
from .base import Base

class User(Base):
    """Entity User"""
    __tablename__ = 'USER'
    uuid:Mapped[str]= mapped_column(String(255), primary_key=True,unique=True,nullable=False,name='UUID',)
    full_name:Mapped[str]= mapped_column(String(255), nullable=False, name='FULL_NAME')
    gender:Mapped[str]= mapped_column(String(255), name='GENDER')
    birthdate:Mapped[datetime]= mapped_column(DateTime, name='BIRTHDATE')
    email:Mapped[str]= mapped_column(String(255), name='EMAIL', unique=True, nullable=False)
    cellphone:Mapped[str]= mapped_column(String(255), name='CELLPHONE', nullable=False)
    create_date:Mapped[datetime]= mapped_column(DateTime, name='CREATE_DATE', default=datetime.now)
    last_update_date:Mapped[datetime]= mapped_column(DateTime, name='LAST_UPDATE_DATE', default=datetime.now, onupdate=datetime.now)
    nick_name:Mapped[str]= mapped_column(String(255), name='NICK_NAME', unique=True,nullable=False)
    device_id:Mapped[str]= mapped_column(String(255), name='DEVICE_ID')
    player_id:Mapped[int]= mapped_column(Integer, ForeignKey('PLAYER.ID'), nullable=True,name='PLAYER_ID')
    city_id:Mapped[int]= mapped_column(Integer, ForeignKey('CITY.ID'), name='CITY_ID')


# setup.py
from setuptools import setup, find_packages

setup(
    name='goallteam_library_entity',
    version='0.0.3',
    packages=find_packages(),
    install_requires=['sqlalchemy'],  # Lista de dependencias
    author='goallteam',
    author_email='kenan249@gmail.com',
    description='Libreria de entidades para goallteam',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/Go-All-Team/library-entity.git',  # Repositorio de GitHub u otro
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.9',
)
